==> qucs_0.0.7.orig.tar.gz: qucs-0.0.7.orig/qucs-core/src/tokens_dataset.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     InvalidCharacter = 258,
     Identifier = 259,
     REAL = 260,
     IMAG = 261,
     COMPLEX = 262,
     Integer = 263,
     Eol = 264,
     IndepBegin = 265,
     DepBegin = 266,
     IndepEnd = 267,
     DepEnd = 268,
     Version = 269
   };
#endif
#define InvalidCharacter 258
#define Identifier 259
#define REAL 260
#define IMAG 261
#define COMPLEX 262
#define Integer 263
#define Eol 264
#define IndepBegin 265
#define DepBegin 266
#define IndepEnd 267
#define DepEnd 268
#define Version 269




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 64 "parse_dataset.y"
typedef union YYSTYPE {
  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  vector * v;
  dataset * data;
  strlist * list;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 78 "tokens_dataset.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE dataset_lval;

==> qucs-0.0.8.tar.gz: qucs-0.0.8/qucs-core/src/tokens_dataset.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     InvalidCharacter = 258,
     Identifier = 259,
     REAL = 260,
     IMAG = 261,
     COMPLEX = 262,
     Integer = 263,
     Eol = 264,
     IndepBegin = 265,
     DepBegin = 266,
     IndepEnd = 267,
     DepEnd = 268,
     Version = 269
   };
#endif
/* Tokens.  */
#define InvalidCharacter 258
#define Identifier 259
#define REAL 260
#define IMAG 261
#define COMPLEX 262
#define Integer 263
#define Eol 264
#define IndepBegin 265
#define DepBegin 266
#define IndepEnd 267
#define DepEnd 268
#define Version 269




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 64 "parse_dataset.y"
typedef union YYSTYPE {
  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  vector * v;
  dataset * data;
  strlist * list;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 79 "tokens_dataset.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE dataset_lval;
